=======
Credits
=======

Development Lead
----------------

* Quantum and High Performance Computing group at University of Oviedo <https://qhpc.uniovi.es>

Contributors
------------

* José Ranilla Pastor - ranilla@uniovi.es
* Elías Fernández Combarro - efernandezca@uniovi.es
* Diego García Vega <garciavdiego@uniovi.es>
* Fernando Álvaro Plou Llorente <ploufernando@uniovi.es>
* Alejandro Leal Castaño <lealcalejandro@uniovi.es>
